![swimlane](https://raw.githubusercontent.com/swimlane/swimlane-python/master/docs/logo.png)

![version](https://img.shields.io/pypi/v/swimlane.svg) ![py-versions](https://img.shields.io/pypi/pyversions/swimlane.svg) ![py-impl](https://img.shields.io/pypi/implementation/swimlane.svg) ![travis](https://travis-ci.org/swimlane/swimlane-python.svg?branch=master) [![Code Climate](https://codeclimate.com/github/swimlane/swimlane-python/badges/gpa.svg)](https://codeclimate.com/github/swimlane/swimlane-python) [![Test Coverage](https://codeclimate.com/github/swimlane/swimlane-python/badges/coverage.svg)](https://codeclimate.com/github/swimlane/swimlane-python/coverage)
---
Python driver for the [Swimlane](http://www.swimlane.com) API

Install via `pip install swimlane` or download [release package](https://github.com/swimlane/swimlane-python/releases).
See the  [documentation](https://swimlane.gitbooks.io/swimlane-python/content/) for more information. Visit [http://support.swimlane.com](http://support.swimlane.com) to log bugs or feature requests.
